==> ToolChain_STM32_1.0.45.tar.bz: ToolChain_STM32_1.0.45/ToolChain/install_15_CPU_STM32L1xx.sh <==
#!/bin/bash

#
#  Install script for combined Microcontroller + 2,4GHz radio STM32 Wxxx 
#  with ARM Cortex M3 core.
#
#  Script written by Gregor Rebel 2012
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="200_cpu_stm32l1xx"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  
  if [ ! -e OK.Documentation ]; then #{
    Dir=`pwd`
    Get_Fails=""
    dir ../../Documentation/uC
    dir ../../Documentation/uC/STM32L1xx
    
    Error=""
    #{ download docs..
#}

    if [ "$Get_Fails" == "" ]; then
      echo "Documentation complete: $INSTALLPATH."
      touch OK.Documentation
    else
      echo "ERROR: Documentations not being received: $Get_Fails"
    fi
  fi #}
  if [ ! -e OK.Install ]; then #{
    
    getFile http://www.st.com/internet/com/SOFTWARE_RESOURCES/SW_COMPONENT/FIRMWARE/ st_zigbee_simplemac.zip STM32W108_SimpleMAC_firmware.zip
    touch OK.Install
  fi #}
  if [   -e OK.Install ]; then #{
    Name="${INSTALLPATH}"
    createExtensionMakefileHead ${Name} #{
    File="../extensions/makefile.${Name}" 
    cat <<END_OF_MAKEFILE >>$File 

ARM_CPU     =arm7tdmi
TARGET      =-mcpu=cortex-m3 -mthumb
TARGET_ARCHITECTURE_CM3=1
TARGET_ARCHITECTURE_STM32=1
TARGET_ARCHITECTURE_PREFIX=STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_PREFIX=STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_STM32
COMPILE_OPTS += -DTARGET_DATA_WIDTH=32

# architecture specific support code
INCLUDE_DIRS += -Iadditionals/common/stm32/
vpath %.c additionals/common/stm32/

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{
    createActivateScriptHead $File $0 "Standard Peripheral Library for CPU STM32W1xx"
    cat <<END_OF_ACTIVATE >>$File #{
rm 2>/dev/null \$Dir_ExtensionsActive/makefile.200_cpu_*

# create links into extensions.active/
createLink ../extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
    
# activate corresponding std_peripheral_library
activate.250_CPAL_STM32L1xx_StdPeriph_Driver.sh QUIET

END_OF_ACTIVATE
#}
    createActivateScriptTail $File $Name
    #}

    echo "Installed successfully: $INSTALLPATH"
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/ToolChain/install_15_CPU_STM32L1xx.sh <==
#!/bin/bash

#
#  Install script for combined Microcontroller + 2,4GHz radio STM32 Wxxx 
#  with ARM Cortex M3 core.
#
#  Script written by Gregor Rebel 2012
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="200_cpu_stm32l1xx"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  
  if [ ! -e OK.Documentation ]; then #{
    Dir=`pwd`
    Get_Fails=""
    dir ../../Documentation/uC
    dir ../../Documentation/uC/STM32L1xx
    
    Error=""
    #{ download docs..
#}

    if [ "$Get_Fails" == "" ]; then
      echo "Documentation complete: $INSTALLPATH."
      touch OK.Documentation
    else
      echo "ERROR: Documentations not being received: $Get_Fails"
    fi
  fi #}
  if [ ! -e OK.Install ]; then #{
    
    getFile http://www.st.com/internet/com/SOFTWARE_RESOURCES/SW_COMPONENT/FIRMWARE/ st_zigbee_simplemac.zip STM32W108_SimpleMAC_firmware.zip
    touch OK.Install
  fi #}
  if [   -e OK.Install ]; then #{
    Name="${INSTALLPATH}"
    createExtensionMakefileHead ${Name} #{
    File="../extensions/makefile.${Name}" 
    cat <<END_OF_MAKEFILE >>$File 

ARM_CPU     =arm7tdmi
TARGET      =-mcpu=cortex-m3 -mthumb
TARGET_ARCHITECTURE_CM3=1
TARGET_ARCHITECTURE_STM32=1
TARGET_ARCHITECTURE_PREFIX=STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_PREFIX=STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_STM32
COMPILE_OPTS += -DTARGET_ARCHITECTURE_CM3
COMPILE_OPTS += -DTARGET_DATA_WIDTH=32

# architecture specific support code
INCLUDE_DIRS += -Icommon/stm32/ -Icommon/cm3
vpath %.c common/stm32/ 
vpath %.c common/cm3


END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{
    createActivateScriptHead $File $0 "Standard Peripheral Library for CPU STM32W1xx"
    cat <<END_OF_ACTIVATE >>$File #{
rm 2>/dev/null \$Dir_ExtensionsActive/makefile.200_cpu_*

# create links into extensions.active/
createLink ../extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET
    
# activate corresponding std_peripheral_library
activate.250_CPAL_STM32L1xx_StdPeriph_Driver.sh QUIET

END_OF_ACTIVATE
#}
    createActivateScriptTail $File $Name
    #}

    echo "Installed successfully: $INSTALLPATH"
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
